%global srcname typer
%global forgeurl https://github.com/tiangolo/typer
%global tag %{version}

Name:           python-typer
Version:        0.4.0
%forgemeta
Release:        %autorelease
Summary:        Build great CLIs; easy to code; based on Python type hints

License:        MIT
URL:            https://typer.tiangolo.com/
Source0:        %{forgesource}
BuildArch:      noarch

BuildRequires:  python3-devel

Obsoletes:      python-typer-doc < 0.4.0-5

%global common_description %{expand:
Typer is a library for building CLI applications that users will love using and
developers will love creating. Based on Python 3.6+ type hints.

The key features are:

  • Intuitive to write: Great editor support. Completion everywhere. Less time
    debugging. Designed to be easy to use and learn. Less time reading docs.
  • Easy to use: It’s easy to use for the final users. Automatic help, and
    automatic completion for all shells.
  • Short: Minimize code duplication. Multiple features from each parameter
    declaration. Fewer bugs.
  • Start simple: The simplest example adds only 2 lines of code to your app: 1
    import, 1 function call.
  • Grow large: Grow in complexity as much as you want, create arbitrarily
    complex trees of commands and groups of subcommands, with options and
    arguments.

Typer is FastAPI’s little sibling.

And it’s intended to be the FastAPI of CLIs.}

%description %{common_description}


%package -n     python3-typer
Summary:        %{summary}

%description -n python3-typer %{common_description}


%pyproject_extras_subpkg -n python3-typer all


%prep
%forgeautosetup
# We must loosen up some strict dependencies to accommodate the versions that
# are packaged. This is always a little risky, but fortunately it affects
# build and test dependencies rather than runtime ones.
#
#   1. We have flit 3.x in Fedora 34 and later, so we must try to use it.
#   2. Filter out formatter/linter/coverage tools that we will not actually use
#      from the test extra requirements; we would not bother, except that many
#      have very strict version pins that we will not be able to satisfy.
#   3. Loosen certain test version pins as well; we must work with what we
#      have. We allow some to be newer.
sed -r -i \
    -e 's/(flit_core[[:blank:]]*>=2[^,]*),<3\b/\1/' \
    -e '/\b(mypy|black|isort|pytest-cov)[[:blank:]]*[>=]=/d' \
    -e 's/\b(pytest(-xdist)?|coverage)([[:blank:]]*>=[^,]*),[^"]+/\1\3/' \
    pyproject.toml

# Remove bundled js-termynal 0.0.1; since we are not building documentation, we
# do this very bluntly:
rm -rvf docs/js docs/css


%generate_buildrequires
%pyproject_buildrequires -x all,test

%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files typer


%check
# See scripts/test.sh. We do not run the linters (scripts/lint.sh, i.e.,
# mypy/black/isort).
./scripts/test-files.sh
# Shell completion tests need us to be running under a supported shell, i.e.
# bash rather than sh. Unfortunately, shell detection with shellingham is so
# thorough we cannot fool it by any combination of:
#  - export SHELL=/bin/bash
#  - bash -c '%%pytest'
#  - %%check -p /bin/bash
# so we must simply skip the affected tests.
%pytest -k 'not test_show_completion and not test_install_completion'


%files -n python3-typer -f %{pyproject_files}
%license LICENSE
%doc CONTRIBUTING.md
%doc README.md


%changelog
%autochangelog
